==> nextcloud-30.0.10.tgz: nextcloud/apps/files_reminders/l10n/ja.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "ファイル リマインダー",
    "Reminder for {name}" : "{name}のリマインダー",
    "View file" : "ファイルを表示",
    "View folder" : "フォルダーを表示",
    "Files reminder" : "ファイル リマインダー",
    "Set file reminders" : "ファイルのリマインダーを設定する",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 File reminders**\n\nファイルのリマインダーを設定します。\n\n注意：`File reminders`アプリを使用するには、`Notifications`アプリがインストールされ、有効になっていることを確認してください。Notifications` アプリは `File reminders` アプリが正しく動作するために必要な API を提供します。",
    "Set reminder for \"{fileName}\"" : "\"{fileName}\"のリマインダーを設定",
    "Set reminder at custom date & time" : "カスタムした日付と時刻にリマインダーを設定",
    "Clear reminder" : "リマインダーをクリア",
    "Please choose a valid date & time" : "有効な日付と時間を選択してください。",
    "Reminder set for \"{fileName}\"" : "\"{fileName}\"のリマインダーを設定しました",
    "Failed to set reminder" : "リマインダーの設定に失敗しました",
    "Reminder cleared for \"{fileName}\"" : "\"{fileName}\"のリマインダーをクリアしました",
    "Failed to clear reminder" : "リマインダーのクリアに失敗しました",
    "We will remind you of this file" : "このファイルをリマインドします",
    "Cancel" : "キャンセル",
    "Set reminder" : "リマインダーを設定",
    "Reminder set" : "リマインダーセット",
    "Set custom reminder" : "カスタムリマインダーを設定する",
    "Later today" : "今日この後",
    "Set reminder for later today" : "今日中にリマインダーを設定する",
    "Tomorrow" : "明日",
    "Set reminder for tomorrow" : "明日のリマインダーを設定する",
    "This weekend" : "この週末",
    "Set reminder for this weekend" : "今週末のリマインダーを設定する",
    "Next week" : "来週",
    "Set reminder for next week" : "来週のリマインダーを設定する",
    "This files_reminder can work properly." : "このfiles_reminderは正しく機能します。",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "files_reminderアプリが正しく動作するには、通知アプリが必要です。通知を有効にするか、files_reminderを無効にしてください。"
},
"nplurals=1; plural=0;");

==> nextcloud-30.0.13.tgz: nextcloud/apps/files_reminders/l10n/ja.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "ファイル リマインダー",
    "Reminder for {name}" : "{name}のリマインダー",
    "View file" : "ファイルを表示",
    "View folder" : "フォルダーを表示",
    "Files reminder" : "ファイル リマインダー",
    "The \"files_reminders\" app can work properly." : "\"files_reminders\"アプリは正しく機能します。",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "\"files_reminder\"アプリが正しく動作するには、通知アプリが必要です。通知を有効にするか、files_reminderを無効にしてください。",
    "Set file reminders" : "ファイルのリマインダーを設定する",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 File reminders**\n\nファイルのリマインダーを設定します。\n\n注意：`File reminders`アプリを使用するには、`Notifications`アプリがインストールされ、有効になっていることを確認してください。Notifications` アプリは `File reminders` アプリが正しく動作するために必要な API を提供します。",
    "Set reminder for \"{fileName}\"" : "\"{fileName}\"のリマインダーを設定",
    "Set reminder at custom date & time" : "カスタムした日付と時刻にリマインダーを設定",
    "Clear reminder" : "リマインダーをクリア",
    "Please choose a valid date & time" : "有効な日付と時間を選択してください。",
    "Reminder set for \"{fileName}\"" : "\"{fileName}\"のリマインダーを設定しました",
    "Failed to set reminder" : "リマインダーの設定に失敗しました",
    "Reminder cleared for \"{fileName}\"" : "\"{fileName}\"のリマインダーをクリアしました",
    "Failed to clear reminder" : "リマインダーのクリアに失敗しました",
    "We will remind you of this file" : "このファイルをリマインドします",
    "Cancel" : "キャンセル",
    "Set reminder" : "リマインダーを設定",
    "Reminder set" : "リマインダーセット",
    "Set custom reminder" : "カスタムリマインダーを設定する",
    "Later today" : "今日この後",
    "Set reminder for later today" : "今日中にリマインダーを設定する",
    "Tomorrow" : "明日",
    "Set reminder for tomorrow" : "明日のリマインダーを設定する",
    "This weekend" : "この週末",
    "Set reminder for this weekend" : "今週末のリマインダーを設定する",
    "Next week" : "来週",
    "Set reminder for next week" : "来週のリマインダーを設定する",
    "This files_reminder can work properly." : "このfiles_reminderは正しく機能します。",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "files_reminderアプリが正しく動作するには、通知アプリが必要です。通知を有効にするか、files_reminderを無効にしてください。"
},
"nplurals=1; plural=0;");
